-- Reno98 - a retro replica of a very recognizable theme
--[[
    Reno98 - A theme for Reno desktop

    Written in 2022 by Yessiest (yessiest@memeware.net)

    To the extent possible under law, the author(s) have dedicated all copyright and related and neighboring rights to this software to the public domain worldwide. This software is distributed without any warranty.

    You should have received a copy of the CC0 Public Domain Dedication along with this software. If not, see <http://creativecommons.org/publicdomain/zero/1.0/>. 
--]]
local theme_assets = require("beautiful.theme_assets")
local xresources = require("beautiful.xresources")
local dpi = xresources.apply_dpi
local gears = require("gears")

local gfs = require("gears.filesystem")
local themes_path = root_path.."/themes/"

local theme = {}

theme.font          = "Terminus 8"

theme.bg_normal     = "#c0c0c0"
theme.bg_focus      = "#D6D3CE"
theme.bg_urgent     = "#FFEDCC"
theme.bg_minimize   = "#efefef"
theme.bg_highlight  = "#D6D3CE"
theme.bg_highlight_shadow = "#404040FF"
theme.bg_highlight_light = "#FFFFFFFF"
theme.bg_highlight_outline = "#808080FF"
theme.bg_systray    = theme.bg_normal

theme.fg_normal     = "#000000"
theme.fg_focus      = "#000000"
theme.fg_urgent     = "#000000"
theme.fg_minimize   = "#000000"

theme.useless_gap   = dpi(0)
-- technically speaking these are irrelevant since they're not exactly smart
-- borders
theme.titlebar_bg_accent_normal_1 = "#808080"
theme.titlebar_bg_accent_normal_2 = "#c0c0c0"
theme.titlebar_bg_accent_focus_1 = "#632210"
theme.titlebar_bg_accent_focus_2 = "#b47856"

theme.border_width  = 0
theme.border_normal = "#c0c0c0"
theme.border_focus  = "#c0c0c0"
theme.border_marked = "#c0c0c0"
theme.window_rounding = 0

theme.titlebar_bg_focus = {
  type = "linear",
  from = { 0, 0 },
  to = { 640, 0 },
  stops = { {0, "#632210"}, {1, "#fed8b1"} }
}

theme.titlebar_bg_normal = {
  type = "linear",
  from = { 0, 0 },
  to = { 640, 0 },
  stops = { {0, "#828282"}, {1, "#AFAFAF"} }
}
local taglist_square_size = dpi(4)
theme.taglist_squares_sel = theme_assets.taglist_squares_sel(
    taglist_square_size, theme.fg_normal
)
theme.taglist_squares_unsel = theme_assets.taglist_squares_unsel(
    taglist_square_size, theme.fg_normal
)
theme.menu_height = dpi(15)
theme.menu_width  = dpi(100)
theme.systray_icon_spacing = 2

-- Define the image to load

theme.titlebar_ontop_button_normal_inactive = themes_path.."serenity/titlebar/ontop_normal_inactive.png"
theme.titlebar_ontop_button_focus_inactive  = themes_path.."serenity/titlebar/ontop_focus_inactive.png"
theme.titlebar_ontop_button_normal_active = themes_path.."serenity/titlebar/ontop_normal_active.png"
theme.titlebar_ontop_button_focus_active  = themes_path.."serenity/titlebar/ontop_focus_active.png"

theme.titlebar_sticky_button_normal_inactive = themes_path.."serenity/titlebar/sticky_normal_inactive.png"
theme.titlebar_sticky_button_focus_inactive  = themes_path.."serenity/titlebar/sticky_focus_inactive.png"
theme.titlebar_sticky_button_normal_active = themes_path.."serenity/titlebar/sticky_normal_active.png"
theme.titlebar_sticky_button_focus_active  = themes_path.."serenity/titlebar/sticky_focus_active.png"

theme.titlebar_floating_button_normal_inactive = themes_path.."serenity/titlebar/floating_normal_inactive.png"
theme.titlebar_floating_button_focus_inactive  = themes_path.."serenity/titlebar/floating_focus_inactive.png"
theme.titlebar_floating_button_normal_active = themes_path.."serenity/titlebar/floating_normal_active.png"
theme.titlebar_floating_button_focus_active  = themes_path.."serenity/titlebar/floating_focus_active.png"

theme = theme_assets.recolor_titlebar(theme,theme.fg_normal,"normal")
theme = theme_assets.recolor_titlebar(theme,theme.fg_focus,"focus")

theme.titlebar_close_button_normal = themes_path.."serenity/titlebar/close_normal.png"
theme.titlebar_close_button_focus  = themes_path.."serenity/titlebar/close_focus.png"

theme.titlebar_minimize_button_normal = themes_path.."serenity/titlebar/minimize_normal.png"
theme.titlebar_minimize_button_focus  = themes_path.."serenity/titlebar/minimize_focus.png"

theme.titlebar_maximized_button_normal_inactive = themes_path.."serenity/titlebar/maximized_normal_inactive.png"
theme.titlebar_maximized_button_focus_inactive  = themes_path.."serenity/titlebar/maximized_focus_inactive.png"
theme.titlebar_maximized_button_normal_active = themes_path.."serenity/titlebar/maximized_normal_active.png"
theme.titlebar_maximized_button_focus_active  = themes_path.."serenity/titlebar/maximized_focus_active.png"

theme.wallpaper = themes_path.."serenity/background.png"
theme.wallpapers_icon = themes_path.."serenity/icons/wallpapers.png"

-- You can use your own layout icons like this:
theme.layout_fairh = themes_path.."serenity/layouts/fairhw.png"
theme.layout_fairv = themes_path.."serenity/layouts/fairvw.png"
theme.layout_floating  = themes_path.."serenity/layouts/floatingw.png"
theme.layout_magnifier = themes_path.."serenity/layouts/magnifierw.png"
theme.layout_max = themes_path.."serenity/layouts/maxw.png"
theme.layout_fullscreen = themes_path.."serenity/layouts/fullscreenw.png"
theme.layout_tilebottom = themes_path.."serenity/layouts/tilebottomw.png"
theme.layout_tileleft   = themes_path.."serenity/layouts/tileleftw.png"
theme.layout_tile = themes_path.."serenity/layouts/tilew.png"
theme.layout_tiletop = themes_path.."serenity/layouts/tiletopw.png"
theme.layout_spiral  = themes_path.."serenity/layouts/spiralw.png"
theme.layout_dwindle = themes_path.."serenity/layouts/dwindlew.png"
theme.layout_cornernw = themes_path.."serenity/layouts/cornernww.png"
theme.layout_cornerne = themes_path.."serenity/layouts/cornernew.png"
theme.layout_cornersw = themes_path.."serenity/layouts/cornersww.png"
theme.layout_cornerse = themes_path.."serenity/layouts/cornersew.png"

-- Generate Awesome icon:
theme.awesome_icon = theme_assets.awesome_icon(
    theme.menu_height, theme.bg_focus, theme.fg_focus
)

theme.hotkeys_border_width = 3
theme.hotkeys_border_color = theme.bg_focus
theme.hotkeys_modifiers_fg = theme.fg_normal
theme.hotkeys_label_fg = theme.fg_normal

theme.bgimage_outset = function(context, cr, width, height,...)
    local light = gears.color(theme.bg_highlight_light)
    local shadow = gears.color(theme.bg_highlight_shadow)
    local outline = gears.color(theme.bg_highlight_outline)
    -- Background

    -- Light
    cr:set_source(light)
    cr.line_width=2
    cr:move_to(0,0)
    cr:line_to(width,0)
    cr:move_to(0,0)
    cr:line_to(0,height)
    cr:stroke()

    -- Outline
    cr:set_source(outline)
    cr:move_to(width-1,height-1)
    cr:line_to(width-1,1)
    cr:move_to(width-2,height-1)
    cr:line_to(1,height-1)
    cr:stroke()

    -- Shadow
    cr:set_source(shadow)
    cr:move_to(width,height)
    cr:line_to(width,0)
    cr:move_to(width-1,height)
    cr:line_to(0,height)
    cr:stroke()
end

theme.bgimage_inset = function(context,cr,width,height)
    local light = gears.color(theme.bg_highlight_light)
    local shadow = gears.color(theme.bg_highlight_shadow)
    local outline = gears.color(theme.bg_highlight_outline)

    -- Light
    cr:set_source(light)
    cr.line_width=2
    cr:move_to(width,height)
    cr:line_to(width,0)
    cr:move_to(width,height)
    cr:line_to(0,height)
    cr:stroke()
    
    -- Shadow
    cr:set_source(shadow)
    cr.line_width=2
    cr:move_to(0,0)
    cr:line_to(0,height)
    cr:move_to(0,0)
    cr:line_to(width,0)
    cr:stroke()
end

theme.bgimage_highlight = function(context,cr,width,height)
    local light = gears.color(theme.bg_highlight_light)
    local shadow = gears.color(theme.bg_highlight_shadow)
    local outline = gears.color(theme.bg_highlight_outline)
    
    -- Light
    cr:set_source(light)
    cr.line_width=2
    cr:move_to(1,1)
    cr:line_to(1,height-2)
    cr:move_to(1,1)
    cr:line_to(width-2,1)
    cr:stroke()
 
    -- Outline
    cr:set_source(outline)
    cr.line_width=2
    cr:rectangle(0,0,width-1,height-1)
    cr:stroke()

    -- Light (bottom)
    cr:set_source(light)
    cr:move_to(width,height)
    cr:line_to(width,0)
    cr:move_to(width,height)
    cr:line_to(0,height)
    cr:stroke()
end

theme.wibar_bgimage_top = function(context, cr, width, height,...)
    local shadow = gears.color(theme.bg_highlight_shadow)
    local outline = gears.color(theme.bg_highlight_outline)
    -- Background

    -- Outline
    cr:set_source(outline)
    cr:move_to(0,height-1)
    cr:line_to(width,height-1)
    cr:stroke()

    -- Shadow
    cr:set_source(shadow)
    cr:move_to(0,height)
    cr:line_to(width,height)
    cr:stroke()
end

theme.wibar_bgimage_bottom = function(context, cr, width, height,...)
    local light = gears.color(theme.bg_highlight_light)
    -- Background

    -- Light
    cr:set_source(light)
    cr.line_width=2
    cr:move_to(0,0)
    cr:line_to(width,0)
    cr:stroke()
end

-- A complex piece of "code" to simulate borders.
theme.titlebar_bgimage_top_focus = function(context, cr, width, height,...)
    local outer_line = gears.color(theme.titlebar_bg_accent_focus_1)
    local inner_line = gears.color(theme.titlebar_bg_accent_focus_2)
    cr.line_width = 2
    cr:set_source(outer_line)
    cr:move_to(1,height)
    cr:line_to(width-1,height)
    cr:stroke()

    cr:set_source(inner_line)
    cr:move_to(1,1)
    cr:line_to(1,height)
    cr:move_to(1,1)
    cr:line_to(width-1,1)
    cr:move_to(width-1,1)
    cr:line_to(width-1,height)
    cr:stroke()

    cr:set_source(outer_line)
    cr:move_to(0,0)
    cr:line_to(0,height)
    cr:move_to(0,0)
    cr:line_to(width,0)
    cr:move_to(width,0)
    cr:line_to(width,height)
    cr:stroke()
end
theme.titlebar_bgimage_bottom_focus = function(context, cr, width, height, ...)
    local outer_line = gears.color(theme.titlebar_bg_accent_focus_1)
    local inner_line = gears.color(theme.titlebar_bg_accent_focus_2)
    cr.line_width = 2
    cr:set_source(inner_line)
    cr:move_to(1,height-1)
    cr:line_to(width-1,height-1)
    cr:move_to(1,height-1)
    cr:line_to(1,0)
    cr:move_to(width-1,height-1)
    cr:line_to(width-1,0)
    cr:stroke()

    cr:set_source(outer_line)
    cr:move_to(0,height)
    cr:line_to(width,height)
    cr:move_to(0,height)
    cr:line_to(0,0)
    cr:move_to(width,height)
    cr:line_to(width,0)
    cr:stroke()
end
theme.titlebar_bgimage_left_focus = function(context, cr, width, height,...)
    local outer_line = gears.color(theme.titlebar_bg_accent_focus_1)
    local inner_line = gears.color(theme.titlebar_bg_accent_focus_2)
    cr.line_width = 2
    cr:set_source(inner_line)
    cr:move_to(1,0)
    cr:line_to(1,height)
    cr:stroke()

    cr:set_source(outer_line)
    cr:move_to(0,0)
    cr:line_to(0,height)
    cr:stroke()
end
theme.titlebar_bgimage_right_focus = function(context, cr, width, height,...)
    local outer_line = gears.color(theme.titlebar_bg_accent_focus_1)
    local inner_line = gears.color(theme.titlebar_bg_accent_focus_2)
    cr.line_width=2
    cr:set_source(inner_line)
    cr:move_to(width-1,0)
    cr:line_to(width-1,height)
    cr:stroke()

    cr:set_source(outer_line)
    cr:move_to(width,0)
    cr:line_to(width,height)
    cr:stroke()
end
theme.titlebar_bgimage_top_normal = function(context, cr, width, height,...)
    local outer_line = gears.color(theme.titlebar_bg_accent_normal_1)
    local inner_line = gears.color(theme.titlebar_bg_accent_normal_2)
    cr.line_width = 2
    cr:set_source(outer_line)
    cr:move_to(1,height)
    cr:line_to(width-1,height)
    cr:stroke()

    cr:set_source(inner_line)
    cr:move_to(1,1)
    cr:line_to(1,height)
    cr:move_to(1,1)
    cr:line_to(width-1,1)
    cr:move_to(width-1,1)
    cr:line_to(width-1,height)
    cr:stroke()

    cr:set_source(outer_line)
    cr:move_to(0,0)
    cr:line_to(0,height)
    cr:move_to(0,0)
    cr:line_to(width,0)
    cr:move_to(width,0)
    cr:line_to(width,height)
    cr:stroke()
end
theme.titlebar_bgimage_bottom_normal = function(context, cr, width, height, ...)
    local outer_line = gears.color(theme.titlebar_bg_accent_normal_1)
    local inner_line = gears.color(theme.titlebar_bg_accent_normal_2)
    cr.line_width = 2
    cr:set_source(inner_line)
    cr:move_to(1,height-1)
    cr:line_to(width-1,height-1)
    cr:move_to(1,height-1)
    cr:line_to(1,0)
    cr:move_to(width-1,height-1)
    cr:line_to(width-1,0)
    cr:stroke()

    cr:set_source(outer_line)
    cr:move_to(0,height)
    cr:line_to(width,height)
    cr:move_to(0,height)
    cr:line_to(0,0)
    cr:move_to(width,height)
    cr:line_to(width,0)
    cr:stroke()
end
theme.titlebar_bgimage_left_normal = function(context, cr, width, height,...)
    local outer_line = gears.color(theme.titlebar_bg_accent_normal_1)
    local inner_line = gears.color(theme.titlebar_bg_accent_normal_2)
    cr.line_width = 2
    cr:set_source(inner_line)
    cr:move_to(1,0)
    cr:line_to(1,height)
    cr:stroke()

    cr:set_source(outer_line)
    cr:move_to(0,0)
    cr:line_to(0,height)
    cr:stroke()
end
theme.titlebar_bgimage_right_normal = function(context, cr, width, height,...)
    local outer_line = gears.color(theme.titlebar_bg_accent_normal_1)
    local inner_line = gears.color(theme.titlebar_bg_accent_normal_2)
    cr.line_width=2
    cr:set_source(inner_line)
    cr:move_to(width-1,0)
    cr:line_to(width-1,height)
    cr:stroke()

    cr:set_source(outer_line)
    cr:move_to(width,0)
    cr:line_to(width,height)
    cr:stroke()
end
---theme.bgimage_outset
-- Define the icon theme for application icons. If not set then the icons
-- from /usr/share/icons and /usr/share/icons/hicolor will be used.
theme.icon_theme = "Chicago95"

-- Icons
local icons = {
    "battery-caution-charging-symbolic",
    "battery-empty-charging-symbolic",
    "battery-full-charging-symbolic",
    "battery-good-charging-symbolic",
    "battery-low-charging-symbolic"
}
for _,v in pairs(icons) do
    theme[v] = themes_path.."serenity/icons/"..v..".png"
    theme[v:gsub("-charging","")] = themes_path.."serenity/icons/"..v:gsub("-charging","")..".png"
end
theme["battery-full-charged-symbolic"] = themes_path.."serenity/icons/battery-full-charged-symbolic.png"
theme["battery-missing-symbolic"] = themes_path.."serenity/icons/battery-missing-symbolic.png"
theme["ac-adapter-symbolic"] = themes_path.."serenity/icons/ac-adapter-symbolic.png"
theme["backlight-symbolic"] = themes_path.."serenity/icons/backlight-symbolic.png"
theme["notifications-area-symbolic"] = themes_path.."serenity/icons/notifications-area-symbolic.png"

theme["mpc-previous-symbolic"] = themes_path.."serenity/icons/mpc-previous-symbolic.png"

theme["mpc-play-symbolic"] = themes_path.."serenity/icons/mpc-play-symbolic.png"
theme["mpc-pause-symbolic"] = themes_path.."serenity/icons/mpc-pause-symbolic.png"
theme["mpc-next-symbolic"] = themes_path.."serenity/icons/mpc-next-symbolic.png"

theme["action-poweroff-symbolic"] = themes_path.."serenity/icons/action-poweroff-symbolic.png"
theme["action-lock-screen-symbolic"] = themes_path.."serenity/icons/action-lock-screen-symbolic.png"
theme["action-suspend-symbolic"] = themes_path.."serenity/icons/action-suspend-symbolic.png"
-- Notification popups settings
theme.notification_width = 240
theme.notification_height = 60

-- Default icon for clients
-- This one has to be baked as a surface to avoid memory leaks
theme.icon_default = gears.surface(themes_path.."serenity/icons/unknown-app.png")

theme.widgets = {
    -- {{{ Widget base
    default = {
        container = {
            bgimage_normal = theme.bgimage_highlight,
            shape = function(cr,width,height)
                return require("gears").shape.rounded_rect(cr,width,height,0)
            end,
            bgimage_highlight = theme.bgimage_inset
        },
        button = {
            bgimage_normal = theme.bgimage_outset,
            shape = function(cr,width,height)
                return require("gears").shape.rounded_rect(cr,width,height,0)
            end,
            onpress = function(widget)
                widget:set_bg(theme.bg_focus)
                widget:set_bgimage(theme.bgimage_inset)
            end,
            onrelease = function(widget)
                widget:set_bg(theme.bg_normal)
                widget:set_bgimage(theme.bgimage_outset)
            end
        },
        popup = {
            bgimage_normal = theme.bgimage_outset,
            shape = function(cr,width,height)
                return gears.shape.rounded_rect(cr,width,height,0)
            end,
        },
        titlebar = {
            hidden_size = 2,
            bgimage_normal = theme.bgimage_outset,
            --margins = 5,
            left = 4,
            right = 5,
            top = 4,
            bottom = 3,
            spacing = 1
        },
        wibar = {
            height = 26,
            width = 60,
            margins = 3,
            shape = function(cr,width,height)
                return gears.shape.rounded_rect(cr,width,height,0)
            end,
            bgimage_normal = theme.bgimage_outset,
            stretch = true
        },
        slider = {
            shape = function(cr,width,height)
                return gears.shape.rounded_rect(cr,width,height,0)
            end,
            height = 20,
            width = 140,
            handle_width = 8,
            handle_border_color = theme.bg_focus,
            handle_border_width = 2,
            bar_height = 6
        }
    },
    -- }}}
    -- {{{ Menus
    generic_menu = {
        base = {
            spacing = 2,
            menu_slide = true
        },
        button = {
            forced_height = 20,
            forced_width = 160
        },
    },
    --}}}
    -- {{{ Bars/Panels/Menu popups
    generic_composite_widget = {
        base = {
            spacing = 2
        }
    },
    generic_iconified_widget = {
        button = {
            margins = 0,
            bgimage_normal = function() end,
            bgimage_focus = function() end,
            onpress = function() end,
            onrelease = function() end
        }
    },
    -- }}}
    -- {{{ Status panel widgets
    generic_status_widget = {
        container = {
            bgimage_normal = function() end,
            margins = 0
        },
        button = {
            margins = 0,
            onpress = function() end,
            onrelease = function() end,
            bgimage_normal = function() end
        }
    },
    -- }}}
    -- {{{ Various button lists
    generic_button_list = {
        button = {
            forced_width = 20,
            forced_height = 20
        },
        base = {
            spacing = 2
        }
    },
    -- }}}
    -- {{{ All widgets that fit into a single line
    generic_oneline_widget = {
        container = {
            bgimage_normal = theme.bgimage_inset
        },
        button = {
            margins = 0,
            bgimage_normal = function() end,
            bgimage_focus = function() end,
            onpress = function() end,
            onrelease = function() end
        }
    },
    -- }}}
    -- {{{ All kinds of widget popups
    generic_popup = {
        button = {
            width = 180,
            height = 40
        },
        article = {
            icon_size = 30
        },
    },
    -- }}}
    popuptitle = {
        container = {
            bg_normal = {
                type = "linear",
                from = { 0, 0 },
                to = { 90, 0 },
                stops = { {0, "#632210"}, {1, "#fed8b1"} }
            },
            -- awesomewm: yo pass me that pango markup
            -- pango: you better not make unintuitive cryptic shit
            -- awesomewm: *attach foreground setting to drawable container*
            fg_normal = "#FAFAFA"
        }
    },
    soundclown = {
        --[[ --Uncomment to leetify that MPC
        container = {
            bg_normal = "#0c0c0c",
            fg_normal = "#00FF00"
        },
        ]]
        base = {
            width = 140,
        },
        container = {
            margins = 1
        }
    },
    subpanel = {
        container = {
            bgimage_normal = theme.bgimage_inset,
            margins = 2
        }
    },
    separator = {
        container = {
            bgimage_normal = function(context, cr, width, height)
                local bar_color = gears.color("#00000070")
                cr.line_width = 1
                cr:set_source(bar_color)
                for i = 0,math.floor(height/2) do
                    cr:move_to(3,(i*2)+0.5)
                    cr:line_to(width-3,(i*2)+0.5)
                end
                cr:stroke()
            end,
            margins = 2,
            bg_normal = "#00000000"
        },
        separator = {
            color = "#30303000"
        }
    },
    taglist = {
        base = {
            spacing = 2,
            layout = require("wibox").layout.flex.horizontal
        },
        button = {
            margins = 2,
            bgimage_focus = theme.bgimage_inset,
            bgimage_normal = theme.bgimage_outset,
        },
        container = {
            margins = 3
        }
    },
    tasklist = {
        button = {
            width = 160,
            height = 50,
            margins = 2,
            bgimage_focus = theme.bgimage_inset,
            bgimage_normal = theme.bgimage_outset,
            bgimage_urgent = theme.bgimage_outset,
            bgimage_minimize = theme.bgimage_outset
        }
    },
    lockscreen = {
        popup = {
            margins = 0
        }
    },
    lockbar = {
        base = {
            height = 22
        }
    },
    lockpanel = {
        base = {
            icon_height = 60,
            icon_width = 60,
            panel_height = 300,
            panel_width = 200,
            panel_bgimage = theme.bgimage_outset
        }
    },
    lock_clock = {
        textbox = {
            font = "Terminus 20"
        }
    },
    titlebar = {
        titlebar_top = {
            bgimage_normal = theme.titlebar_bgimage_top_normal,
            bgimage_focus = theme.titlebar_bgimage_top_focus,
            bg_focus = theme.titlebar_bg_focus,
            bg_normal = theme.titlebar_bg_normal,
            fg_focus = "#FAFAFA",
            fg_normal = theme.fg_normal,
            size = 22,
        },
        titlebar_left = {
            bgimage_normal = theme.titlebar_bgimage_left_normal,
            bgimage_focus = theme.titlebar_bgimage_left_focus,
            size = 3,
            bg_focus = theme.titlebar_bg_accent_focus_1,
            bg_normal = theme.titlebar_bg_accent_normal_1
        },
        titlebar_right = {
            bgimage_normal = theme.titlebar_bgimage_right_normal,
            bgimage_focus = theme.titlebar_bgimage_right_focus,
            size = 3,
            bg_focus = theme.titlebar_bg_accent_focus_1,
            bg_normal = theme.titlebar_bg_accent_normal_1
        },
        titlebar_bottom = {
            bgimage_normal = theme.titlebar_bgimage_bottom_normal,
            bgimage_focus = theme.titlebar_bgimage_bottom_focus,
            size = 3,
            bg_focus = theme.titlebar_bg_accent_focus_1,
            bg_normal = theme.titlebar_bg_accent_normal_1
        }
    },
    wibar = {
        wibar_top = {
            height = 22,
            bgimage_normal = theme.wibar_bgimage_top,
        },
        wibar_bottom = {
            height = 26,
            bgimage_normal = theme.wibar_bgimage_bottom
        }
    }
}

return theme

-- vim: filetype=lua:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:textwidth=80
